SkmvConfig

Struct SkmvConfig 

pub struct SkmvConfig {
    pub maximum_capacity: usize,
    pub maximum_values_per_key: usize,
    pub idle_timeout: Option<u32>,
    pub time_to_live: Option<u32>,
}
Configuration for the SkmvCache initialization via SkmvCache::new.

Fields

maximum_capacity: usize

Maximum number of keys in the cache.

maximum_values_per_key: usize

Maximum number of values per key.

idle_timeout: Option<u32>

Idle timeout for each key in the cache. When key expires due to inactivity all associated values are also removed.

Default is 60 seconds.

time_to_live: Option<u32>

Time to live for each key in the cache. When key expires due to timeout all associated values are also removed.

Default is 60 seconds.